@@ -19,18 +19,18 @@ our $cc = $Config{cc};
 
 my $prebuilt_binaries = [
     {
-      title    => "Binaries Win/32bit CMake-2.8.12.1",
-      url      => 'http://www.cmake.org/files/v2.8/cmake-2.8.12.1-win32-x86.zip',
-      version  => '2.8.12.1',
-      sha1sum  => '6a27d8fcf887774e56fa165eddd5242e1c350464',
+      title    => "Binaries Win/32bit CMake-3.3.0",
+      url      => 'http://www.cmake.org/files/v3.3/cmake-3.3.0-win32-x86.zip',
+      version  => '3.3.0',
+      sha1sum  => '8e6493601704bf34bfda4f5796d2362bc0091bcc',
       arch_re  => qr/^MSWin32-x(86|64)-multi-thread(-64int)?$/,
       os_re    => qr/^MSWin32$/
     },
     {
-      title    => "Binaries Linux/i386 CMake-2.8.12.1",
-      url      => 'http://www.cmake.org/files/v2.8/cmake-2.8.12.1-Linux-i386.tar.gz',
-      version  => '2.8.12.1',
-      sha1sum  => 'b157f5b0fb2209b967dd087b1c166bfe229c56b8',
+      title    => "Binaries Linux/i386 CMake-3.3.0",
+      url      => 'http://www.cmake.org/files/v3.3/cmake-3.3.0-Linux-i386.tar.gz',
+      version  => '3.3.0',
+      sha1sum  => '0fff21ec9b62b54c206c63b141b568983cb07ea4',
       arch_re  => qr/(86.*linux|linux.*86)/,
       os_re    => qr/^linux$/
     },
@@ -59,18 +59,18 @@ my $prebuilt_binaries = [
       os_re    => qr/^openbsd$/
     },
     {
-      title    => "Binaries SunOS/Solaris CMake-2.8.4",
-      url      => 'http://www.cmake.org/files/v2.8/cmake-2.8.4-SunOS-sparc.tar.gz',
-      version  => '2.8.4',
-      sha1sum  => '068c20450ee7e3074ac4c8396e3fa73f28aba35d',
+      title    => "Binaries SunOS/Solaris CMake-2.8.5",
+      url      => 'http://www.cmake.org/files/v2.8/cmake-2.8.5-SunOS-sparc.tar.gz',
+      version  => '2.8.5',
+      sha1sum  => '500ee64f5ce63dded1bd16296d657425b6d4ecb5',
       arch_re  => qr/./,
       os_re    => qr/^solaris$/
     },
     {
-      title    => "Binaries darwin CMake-2.8.4",
-      url      => 'http://www.cmake.org/files/v2.8/cmake-2.8.4-Darwin-universal.tar.gz',
-      version  => '2.8.4',
-      sha1sum  => '190d9e536ed78c756e875747aedcad507fba74a8',
+      title    => "Binaries darwin CMake-3.3.0",
+      url      => 'http://www.cmake.org/files/v3.3/cmake-3.3.0-Darwin-universal.tar.gz',
+      version  => '3.3.0',
+      sha1sum  => '8da844f649aa29638ede16d92d0606a33ebc52c9',
       arch_re  => qr/./,
       os_re    => qr/^darwin$/
     },
@@ -153,7 +153,7 @@ sub find_CMake_dir {
   # try to find 
   my ($found) = find_file($root, qr/[\\\/]bin[\\\/]cmake(\.exe)?$/i ); # take just the first one
   return unless $found;
-  
+
   # get prefix dir
   my ($v, $d, $f) = splitpath($found);
   my @pp = reverse splitdir($d);
