@@ -13,11 +13,11 @@ Alien::CMake - Build and make available CMake library - L<http://cmake.org/>
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 $VERSION = eval $VERSION;
 
 =head1 SYNOPSIS
@@ -73,6 +73,11 @@ This function is the main public interface to this module:
     Alien::CMake->config('libs');
     Alien::CMake->config('cflags');
 
+=head2 bin_dir()
+
+For compatability with L<Alien::Base>, this will return the path containing C<cmake>
+or empty list if it is already in the C<PATH>.
+
 =head1 BUGS
 
 Please post issues and bugs at L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Alien-CMake>
@@ -154,4 +159,11 @@ sub _cmake_config_via_config_data
   return $val;
 }
 
+sub bin_dir
+{
+  !Alien::CMake::ConfigData->config('script')
+    ? (Alien::CMake->config('bin'))
+    : ();
+}
+
 1;
